[LON-CAPA-cvs] cvs: loncom /interface lonnavmaps.pm

banghart lon-capa-cvs-allow@mail.lon-capa.org
Fri, 27 Apr 2007 17:59:52 -0000


banghart		Fri Apr 27 13:59:52 2007 EDT

  Modified files:              
    /loncom/interface	lonnavmaps.pm 
  Log:
  	Correct typos in documentation.
  
  
Index: loncom/interface/lonnavmaps.pm
diff -u loncom/interface/lonnavmaps.pm:1.397 loncom/interface/lonnavmaps.pm:1.398
--- loncom/interface/lonnavmaps.pm:1.397	Thu Jan 11 16:09:39 2007
+++ loncom/interface/lonnavmaps.pm	Fri Apr 27 13:59:50 2007
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Navigate Maps Handler
 #
-# $Id: lonnavmaps.pm,v 1.397 2007/01/11 21:09:39 albertel Exp $
+# $Id: lonnavmaps.pm,v 1.398 2007/04/27 17:59:50 banghart Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -85,7 +85,7 @@
       $resObj->PARTIALLY_CORRECT      => '#006600'
       );
 # And a special case in the nav map; what to do when the assignment
 # is not yet done and due in less then 24 hours
 my $hurryUpColor = "#FF0000";
 
 sub close {
@@ -238,7 +238,7 @@
     }
 }
 
 # Convenience function, so others can use it: Is the problem due in less then
 # 24 hours, and still can be done?
 
 sub dueInLessThan24Hours {
@@ -253,7 +253,7 @@
 }
 
 # Convenience function, so others can use it: Is there only one try remaining for the
 # part, with more then one try to begin with, not due yet and still can be done?
 sub lastTry {
     my $res = shift;
     my $part = shift;
@@ -322,13 +322,13 @@
         my $tense = $inPast ? " ago" : "";
         my $prefix = $inPast ? "" : "in ";
         
         # Less then a minute
         if ( $delta < $minute ) {
             if ($delta == 1) { return "${prefix}1 second$tense"; }
             return "$prefix$delta seconds$tense";
         }
 
         # Less then an hour
         if ( $delta < $hour ) {
             # If so, use minutes
             my $minutes = floor($delta / 60);
@@ -336,7 +336,7 @@
             return "$prefix$minutes minutes$tense";
         }
         
         # Is it less then 24 hours away? If so,
         # display hours + minutes
         if ( $delta < $hour * 24) {
             my $hours = floor($delta / $hour);
@@ -362,7 +362,7 @@
 	    return $timeStr.&Apache::lonlocal::gettimezone($time);
 	}
 
         # Less then 5 days away, display day of the week and
         # HH:MM
 
         if ( $delta < $day * 5 ) {
@@ -427,7 +427,7 @@
 processed.
 
 Apache::lonnavmaps provides an object model for manipulating this
-information in a higher-level fashion then directly manipulating 
+information in a higher-level fashion than directly manipulating 
 the hash. It also provides access to several auxilary functions 
 that aren't necessarily stored in the Big Hash, but are a per-
 resource sort of value, like whether there is any feedback on 
@@ -473,7 +473,7 @@
 =head2 Overview of Columns
 
 The renderer will build an HTML table for the navmap and return
-it. The table is consists of several columns, and a row for each
+it. The table consists of several columns, and a row for each
 resource (or possibly each part). You tell the renderer how many
 columns to create and what to place in each column, optionally using
 one or more of the prepared columns, and the renderer will assemble
@@ -2197,7 +2197,7 @@
 
 # The strategy here is to cache the resource objects, and only construct them
 # as we use them. The real point is to prevent reading any more from the tied
 # hash then we have to, which should hopefully alleviate speed problems.
 
 sub getById {
     my $self = shift;
@@ -2398,7 +2398,7 @@
 =item * B<getResourceByUrl>(url,multiple):
 
 Retrieves a resource object by URL of the resource, unless the optional
-multiple parameter is included in wahich caes an array of resource 
+multiple parameter is included in which case an array of resource 
 objects is returned. If passed a resource object, it will simply return  
 it, so it is safe to use this method in code like
 "$res = $navmap->getResourceByUrl($res)"
@@ -2433,7 +2433,7 @@
 
 =item * B<hasResource>(map, filterFunc, recursive, showall):
 
-Convience method for
+Convenience method for
 
  scalar(retrieveResources($map, $filterFunc, $recursive, 1, $showall)) > 0
 
@@ -2667,7 +2667,7 @@
 
 Also note there is some old code floating around that trys to track
 the depth of the iterator to see when it's done; do not copy that 
-code. It is difficult to get right and harder to understand then
+code. It is difficult to get right and harder to understand than
 this. They should be migrated to this new style.
 
 =cut
@@ -2952,7 +2952,7 @@
     }
 
     # Is this the end of a branch? If so, all of the resources examined above
     # led to lower levels then the one we are currently at, so we push a END_BRANCH
     # marker onto the stack so we don't forget.
     # Example: For the usual A(BC)(DE)F case, when the iterator goes down the
     # BC branch and gets to C, it will see F as the only next resource, but it's
@@ -3288,7 +3288,7 @@
 All resources also have B<symb>s, which uniquely identify a resource
 in a course. Many internal LON-CAPA functions expect a symb. A symb
 carries along with it the URL of the resource, and the map it appears
-in. Symbs are much larger then resource IDs.
+in. Symbs are much larger than resource IDs.
 
 =cut
 
@@ -3665,9 +3665,9 @@
 
 # These functions will be responsible for returning the CORRECT
 # VALUE for the parameter, no matter what. So while they may look
 # like direct calls to parmval, they can be more then that.
 # So, for instance, the duedate function should use the "duedatetype"
 # information, rather then the resource object user.
 
 =pod
@@ -85,7 +85,7 @@
       );
 # And a special case in the nav map; what to do when the assignment
-# is not yet done and due in less then 24 hours
+# is not yet done and due in less than 24 hours
 my $hurryUpColor = "#FF0000";
 
@@ -238,7 +238,7 @@
 }
 
-# Convenience function, so others can use it: Is the problem due in less then
+# Convenience function, so others can use it: Is the problem due in less than
 # 24 hours, and still can be done?
 
@@ -253,7 +253,7 @@
 
 # Convenience function, so others can use it: Is there only one try remaining for the
-# part, with more then one try to begin with, not due yet and still can be done?
+# part, with more than one try to begin with, not due yet and still can be done?
 sub lastTry {
     my $res = shift;
@@ -322,13 +322,13 @@
         my $prefix = $inPast ? "" : "in ";
         
-        # Less then a minute
+        # Less than a minute
         if ( $delta < $minute ) {
             if ($delta == 1) { return "${prefix}1 second$tense"; }
@@ -322,13 +322,13 @@
         }
 
-        # Less then an hour
+        # Less than an hour
         if ( $delta < $hour ) {
             # If so, use minutes
@@ -336,7 +336,7 @@
         }
         
-        # Is it less then 24 hours away? If so,
+        # Is it less than 24 hours away? If so,
         # display hours + minutes
         if ( $delta < $hour * 24) {
@@ -362,7 +362,7 @@
 	}
 
-        # Less then 5 days away, display day of the week and
+        # Less than 5 days away, display day of the week and
         # HH:MM
 
@@ -2197,7 +2197,7 @@
 # The strategy here is to cache the resource objects, and only construct them
 # as we use them. The real point is to prevent reading any more from the tied
-# hash then we have to, which should hopefully alleviate speed problems.
+# hash than we have to, which should hopefully alleviate speed problems.
 
 sub getById {
@@ -2952,7 +2952,7 @@
 
     # Is this the end of a branch? If so, all of the resources examined above
-    # led to lower levels then the one we are currently at, so we push a END_BRANCH
+    # led to lower levels than the one we are currently at, so we push a END_BRANCH
     # marker onto the stack so we don't forget.
     # Example: For the usual A(BC)(DE)F case, when the iterator goes down the
@@ -3665,9 +3665,9 @@
 # These functions will be responsible for returning the CORRECT
 # VALUE for the parameter, no matter what. So while they may look
-# like direct calls to parmval, they can be more then that.
+# like direct calls to parmval, they can be more than that.
 # So, for instance, the duedate function should use the "duedatetype"
@@ -3665,9 +3665,9 @@
 # So, for instance, the duedate function should use the "duedatetype"
-# information, rather then the resource object user.
+# information, rather than the resource object user.
 
 =pod